# Syntax diagrams

Render syntax diagrams (a.k.a. railroad diagrams) with ease.

## Resources

- [Documentation](https://syntax-diagrams.readthedocs.io/en/stable/)
- [Quickstart](https://syntax-diagrams.readthedocs.io/en/stable/quickstart.html)
- [Try it in your browser](https://syntax-diagrams.readthedocs.io/en/stable/try)

## Requirements

- python >= 3.12

## Installation

```sh
pip install syntax-diagrams
```
